@@ -21,12 +21,29 @@ if (!defined('POSTFIXADMIN')) { # already defined if called from setup.php
     if (!defined('POSTFIXADMIN_CLI')) {
         // this is the default; see also https://sourceforge.net/p/postfixadmin/bugs/347/
         session_cache_limiter('nocache');
+
+        /**
+         * @see https://github.com/postfixadmin/postfixadmin/issues/903
+         */
+        $cookie_params = session_get_cookie_params();
+        $cookie_params['samesite'] = 'Strict';
+        $cookie_params['httponly'] = true;
+        // Is this worthwhile? a non https request will get a non 'secure' cookie.
+        if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') {
+            $cookie_params['secure'] = true;
+        }
+        session_set_cookie_params($cookie_params);
         session_name('postfixadmin_session');
         session_start();
 
         if (empty($_SESSION['flash'])) {
             $_SESSION['flash'] = array();
         }
+
+        // avoid clickjacking attacks?
+        header('X-Frame-Options: DENY');
+        // see https://github.com/postfixadmin/postfixadmin/issues/905
+        header("Content-Security-Policy: default-src 'self'; script-src 'self' 'unsafe-inline'; style-src 'self' 'unsafe-inline';");
     }
 }
 
@@ -88,7 +105,7 @@ if (!empty($CONF['language_hook']) && function_exists($CONF['language_hook'])) {
 Config::write('__LANG', $PALANG);
 
 if (!defined('POSTFIXADMIN_CLI')) {
-    if (!isset($CONF) || !isset($PALANG)) {
+    if (!isset($PALANG)) {
         die("environment not setup correctly");
     }
     require_once(__DIR__  . '/lib/smarty/libs/Autoloader.php');
