@@ -1,4 +1,5 @@
 <?php
+
 /* vim: set expandtab softtabstop=4 tabstop=4 shiftwidth=4: */
 
 # Note: run with upgrade.php?debug=1 to see all SQL error messages
@@ -163,8 +164,8 @@ function _do_upgrade($current_version) {
     foreach ($our_upgrade_functions as $function_name) {
         $bits = explode("_", $function_name);
         $function_number = $bits[1];
-        if ($function_number > $current_version && $function_number > $target_version) {
-            $target_version = $function_number;
+        if (is_numeric($function_number)) {
+            $target_version = max($target_version, $function_number);
         }
     }
 
@@ -331,6 +332,8 @@ function db_query_parsed($sql, $ignore_errors = 0, $attach_mysql = "") {
         if ($debug) {
             echo_out("<div style='color:#f00'>" . $e->getMessage() . "</div>");
         }
+
+        throw new \Exception("Postfixadmin DB update failed. Please check your PHP error_log");
     }
 }
 /**
@@ -1827,9 +1830,7 @@ function upgrade_1836_mysql() {
  * @return void
  */
 function upgrade_1837() {
-    global $CONF;
-
-    if ($CONF['database_type'] == 'sqlite') {
+    if (db_sqlite()) {
         return;
     }
     # alternative contact means to reset a forgotten password
@@ -1878,6 +1879,10 @@ function upgrade_1837_sqlite() {
  */
 function upgrade_1839() {
     if (!db_sqlite()) {
+        // Note: mysql-8 may have silently added a my_row_id auto increment field
+        // see https://dev.mysql.com/doc/refman/8.4/en/create-table-gipks.html
+        // and https://github.com/postfixadmin/postfixadmin/issues/908
+        // fix: change the sql_generate_invisible_primary_key MySQL parameter to be off / 0
         _db_add_field('log', 'id', '{AUTOINCREMENT} {PRIMARY}', 'data');
         return;
     }
@@ -1924,6 +1929,14 @@ function upgrade_1841_sqlite() {
  * @return void
  */
 function upgrade_1842() {
+    $domain = table_by_key('domain');
+
+    // See: https://github.com/postfixadmin/postfixadmin/issues/489
+    // Avoid : ERROR 1292 (22007): Incorrect datetime value: '0000-00-00 00:00:00' for column 'created' at row 1
+    if (db_mysql()) {
+        db_execute("UPDATE $domain SET created='2000-01-01 00:00:00', modified='2000-01-01 00:00:00' WHERE domain='ALL'", [], true);
+    }
+
     _db_add_field('mailbox', 'password_expiry', "{DATETIME}"); // when a specific mailbox password expires
     _db_add_field('domain',  'password_expiry', 'int DEFAULT 0'); // expiry applied to mailboxes within that domain
 }
@@ -1935,3 +1948,76 @@ function upgrade_1843() {
     # Additional field for fetchmail to allow server with non-standard port number
     _db_add_field('fetchmail', 'src_port', "{INT}", 'src_server');
 }
+
+
+/**
+ * @return void
+ */
+function upgrade_1844() {
+    # See:https://github.com/postfixadmin/postfixadmin/issues/475 - add pkey to domain_admins.
+
+    if (db_sqlite()) {
+        return;
+    }
+
+    _db_add_field('domain_admins', 'id', '{AUTOINCREMENT} {PRIMARY}');
+}
+
+function upgrade_1845() {
+    # See: https://github.com/postfixadmin/postfixadmin/pull/484
+    #
+    if (!db_mysql()) {
+        return;
+    }
+
+    $vacation = table_by_key('vacation');
+    $mailbox = table_by_key('mailbox');
+    db_query("alter table $vacation change body body text charset utf8mb4 not null");
+    db_query("alter table $vacation change subject subject varchar(255) charset utf8mb4 not null");
+    db_query("alter table $mailbox change name name varchar(255) charset utf8mb4 not null");
+}
+
+function upgrade_1846_mysql() {
+    # See https://github.com/postfixadmin/postfixadmin/issues/327
+
+    $alias = table_by_key('alias');
+    $domain = table_by_key('domain');
+    $mailbox = table_by_key('mailbox');
+    $vacation = table_by_key('vacation');
+    $vacation_notification = table_by_key('vacation_notification');
+    $alias_domain = table_by_key('alias_domain');
+    $domain_admins = table_by_key('domain_admins');
+
+    db_query("ALTER TABLE $alias MODIFY address varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $alias MODIFY goto text  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $alias MODIFY domain varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $domain MODIFY domain varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $domain MODIFY transport varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY username varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY password varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY maildir varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY local_part varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $mailbox MODIFY domain varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $vacation_notification DROP FOREIGN KEY vacation_notification_pkey");
+    db_query("ALTER TABLE $vacation MODIFY domain varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $vacation MODIFY email varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $alias_domain MODIFY alias_domain varchar(255)  COLLATE latin1_general_ci NOT NULL DEFAULT ''");
+    db_query("ALTER TABLE $alias_domain MODIFY target_domain varchar(255)  COLLATE latin1_general_ci NOT NULL DEFAULT ''");
+
+    db_query("ALTER TABLE $vacation_notification MODIFY on_vacation VARCHAR(255) COLLATE latin1_general_ci NOT NULL");
+    db_query("ALTER TABLE $vacation_notification ADD CONSTRAINT vacation_notification_pkey FOREIGN KEY (`on_vacation`) REFERENCES $vacation(email) ON DELETE CASCADE");
+
+    db_query("ALTER TABLE $domain_admins MODIFY `domain` varchar(255) COLLATE latin1_general_ci NOT NULL");
+}
+
+function upgrade_1847_mysql() {
+    # See https://github.com/postfixadmin/postfixadmin/issues/327
+    # See https://github.com/postfixadmin/postfixadmin/issues/690
+    #
+    #
+
+    foreach (['quota','quota2'] as $table) {
+        $table = table_by_key($table);
+        db_query("ALTER TABLE $table MODIFY username varchar(255)  COLLATE latin1_general_ci NOT NULL");
+    }
+}
